==> cutter-0.3.0.tar.gz: cutter-0.3.0/cutter/cut-enum-types.c <==

/* Generated data (by glib-mkenums) */

#include "cut-enum-types.h"
#include "cut-public.h"
#include "cut-private.h"
#include "cut-runner.h"
#include "cut-main.h"
#include "cut-test.h"
#include "cut-test-case.h"
#include "cut-test-container.h"
#include "cut-test-context.h"
#include "cut-test-suite.h"
#include "cut-test-result.h"
#include "cut-ui.h"
#include "cut-ui-factory.h"
#include "cut-verbose-level.h"

/* enumerations from "cut-public.h" */
GType
cut_test_result_status_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { CUT_TEST_RESULT_SUCCESS, "CUT_TEST_RESULT_SUCCESS", "success" },
      { CUT_TEST_RESULT_NOTIFICATION, "CUT_TEST_RESULT_NOTIFICATION", "notification" },
      { CUT_TEST_RESULT_PENDING, "CUT_TEST_RESULT_PENDING", "pending" },
      { CUT_TEST_RESULT_FAILURE, "CUT_TEST_RESULT_FAILURE", "failure" },
      { CUT_TEST_RESULT_ERROR, "CUT_TEST_RESULT_ERROR", "error" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("CutTestResultStatus", values);
  }
  return etype;
}
GType
cut_verbose_level_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { CUT_VERBOSE_LEVEL_SILENT, "CUT_VERBOSE_LEVEL_SILENT", "silent" },
      { CUT_VERBOSE_LEVEL_NORMAL, "CUT_VERBOSE_LEVEL_NORMAL", "normal" },
      { CUT_VERBOSE_LEVEL_VERBOSE, "CUT_VERBOSE_LEVEL_VERBOSE", "verbose" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("CutVerboseLevel", values);
  }
  return etype;
}
GType
cut_verbose_level_error_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { CUT_VERBOSE_LEVEL_ERROR_BAD_VALUE, "CUT_VERBOSE_LEVEL_ERROR_BAD_VALUE", "value" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("CutVerboseLevelError", values);
  }
  return etype;
}

/* Generated data ends here */

==> cutter-0.4.0.tar.gz: cutter-0.4.0/cutter/cut-enum-types.c <==

/* Generated data (by glib-mkenums) */

#include "cut-enum-types.h"
#include "cut-public.h"
#include "cut-private.h"
#include "cut-runner.h"
#include "cut-main.h"
#include "cut-test.h"
#include "cut-test-case.h"
#include "cut-test-container.h"
#include "cut-test-context.h"
#include "cut-test-suite.h"
#include "cut-test-result.h"
#include "cut-ui.h"
#include "cut-ui-factory.h"
#include "cut-report.h"
#include "cut-verbose-level.h"

/* enumerations from "cut-public.h" */
GType
cut_test_result_status_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { CUT_TEST_RESULT_SUCCESS, "CUT_TEST_RESULT_SUCCESS", "success" },
      { CUT_TEST_RESULT_NOTIFICATION, "CUT_TEST_RESULT_NOTIFICATION", "notification" },
      { CUT_TEST_RESULT_PENDING, "CUT_TEST_RESULT_PENDING", "pending" },
      { CUT_TEST_RESULT_FAILURE, "CUT_TEST_RESULT_FAILURE", "failure" },
      { CUT_TEST_RESULT_ERROR, "CUT_TEST_RESULT_ERROR", "error" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("CutTestResultStatus", values);
  }
  return etype;
}
GType
cut_report_file_mode_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { CUT_REPORT_FILE_OVERWRITE, "CUT_REPORT_FILE_OVERWRITE", "overwrite" },
      { CUT_REPORT_FILE_APPEND, "CUT_REPORT_FILE_APPEND", "append" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("CutReportFileMode", values);
  }
  return etype;
}
GType
cut_verbose_level_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { CUT_VERBOSE_LEVEL_SILENT, "CUT_VERBOSE_LEVEL_SILENT", "silent" },
      { CUT_VERBOSE_LEVEL_NORMAL, "CUT_VERBOSE_LEVEL_NORMAL", "normal" },
      { CUT_VERBOSE_LEVEL_VERBOSE, "CUT_VERBOSE_LEVEL_VERBOSE", "verbose" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("CutVerboseLevel", values);
  }
  return etype;
}
GType
cut_verbose_level_error_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { CUT_VERBOSE_LEVEL_ERROR_BAD_VALUE, "CUT_VERBOSE_LEVEL_ERROR_BAD_VALUE", "value" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("CutVerboseLevelError", values);
  }
  return etype;
}

/* Generated data ends here */
